# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
import re


def get_version():
    """Get the current version of the hotness package"""
    with open('simple_koji_ci/__init__.py', 'r') as fd:
        regex = r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]'
        version = re.search(regex, fd.read(), re.MULTILINE).group(1)
    if not version:
        raise RuntimeError('No version set in simple_koji_ci/__init__.py')
    return version


def get_requirements(requirements_file='requirements.txt'):
    """Get the contents of a file listing the requirements.

    :arg requirements_file: path to a requirements file
    :type requirements_file: string
    :returns: the list of requirements, or an empty list if
              `requirements_file` could not be opened or read
    :return type: list
    """

    lines = open(requirements_file).readlines()
    return [
        line.rstrip().split('#')[0]
        for line in lines
        if not line.startswith('#')
    ]


setup(
    name='simple-koji-ci',
    version=get_version(),
    description='Consume pagure fedmsg messages to test pull-request',
    license='GPLv2+',
    author='Pierre-Yves Chibon',
    author_email='pingou@pingoured.fr',
    url='https://pagure.io/simple-koji-ci',
    install_requires=get_requirements(),
    tests_require=get_requirements('dev-requirements.txt'),
    packages=find_packages(
        exclude=('simple_koji_ci.tests', 'simple_koji_ci.tests.*')),
    test_suite='simple_koji_ci.tests',
    entry_points="""
    [moksha.consumer]
    koji_ci = simple_koji_ci.consumers:SimpleKojiCi
    """,
)
